package com.hzya.frame.plugin.lets.util;

import cn.hutool.core.lang.Assert;
import com.hzya.frame.beanutil.BeanUtil;
import com.hzya.frame.ttxofs.dto.ofssalesordersearch.DetailsDto;
import com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto;
import com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDto;
import com.hzya.frame.ttxofs.dto.returngoodordersearch.RerturnGoodsOrderSearchData;
import com.hzya.frame.ttxofs.dto.returngoodordersearch.RerturnGoodsOrderSearchDetails;
import com.hzya.frame.ttxofs.dto.returngoodordersearch.RerturnGoodsOrderSearchHeader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * 处理OFS售后订单，优惠金额分摊逻辑
 *
 * @Author：liuyang
 * @Package：com.hzya.frame.plugin.lets.util
 * @Project：kangarooDataCenterV3
 * @name：AmountAllocationUtil
 * @Date：2024/9/21 18:19
 * @Filename：AmountAllocationUtil
 */
@Component
public class OfsOrderAfterSalesAmountAllocationUtil {

    Logger logger = LoggerFactory.getLogger(OfsOrderAfterSalesAmountAllocationUtil.class);

    /**
     * TOC售后订单金额批量分摊
     *
     * @author liuyang
     */
    public void batchTocSalesAmountAllocation(List<RerturnGoodsOrderSearchData> rerturnGoodsOrderSearchDataList) {
        Assert.notNull(rerturnGoodsOrderSearchDataList, "rerturnGoodsOrderSearchDataList不能为空！");

        rerturnGoodsOrderSearchDataList.forEach(rerturnGoodsOrderSearchData -> {
            try {
                tocSalesAmountAllocation(rerturnGoodsOrderSearchData);
            } catch (Exception e) {
                logger.error("batchTocSalesAmountAllocation方法抛出异常，批量处理TOC售后订单分摊异常", e);
            }
        });
//        logger.info("=记录优惠金额分摊结果开始=");
//        printAmountOfMoneyNum(rerturnGoodsOrderSearchDataList);
//        logger.info("=记录优惠金额分摊结果完成=");
    }

    /**
     * TOC销售金额分摊
     *
     * @param rerturnGoodsOrderSearchData OFS售后订单
     * @author liuyang
     */
    public void tocSalesAmountAllocation(RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData) throws Exception {
        Assert.notNull(rerturnGoodsOrderSearchData, "rerturnGoodsOrderSearchData不能为空");
        logger.info("==TOC退货金额分摊开始==");

        //测试
//        RerturnGoodsOrderSearchHeader header2 = rerturnGoodsOrderSearchData.getHeader();
//        header2.setPlatformDiscounts("3.75");
//        header2.setMerchantDiscounts("7.88");
//        header2.setExpertDiscounts("4.22");
//        header2.setPayDiscounts("1.96");

        Assert.notNull(rerturnGoodsOrderSearchData, "OFS售后订单对象不能为空");
        RerturnGoodsOrderSearchHeader header = rerturnGoodsOrderSearchData.getHeader();
        List<RerturnGoodsOrderSearchDetails> detailsOld = rerturnGoodsOrderSearchData.getDetails();

        //拷贝一份List集合，并移除没有实付金额的原始
        //暂时取零售价作为分类的标准，需要和万万确认一下
        //已经和万万确认
        List<RerturnGoodsOrderSearchDetails> rerturnGoodsOrderSearchDetails = copyDetailsDto(detailsOld);
        rerturnGoodsOrderSearchDetails.removeIf(dto -> dto.getMsrPrice() == null || "0".equals(new BigDecimal(dto.getMsrPrice()).stripTrailingZeros().toPlainString()));

        //计算分摊百分比
        calculatePercentage(rerturnGoodsOrderSearchData, rerturnGoodsOrderSearchDetails, header.getCode());

        String platformDiscounts = header.getPlatformDiscounts();
        String merchantDiscounts = header.getMerchantDiscounts();
        String expertDiscounts = header.getExpertDiscounts();
        String payDiscounts = header.getPayDiscounts();

        BigDecimal targetPlatformDiscounts = null;
        BigDecimal targetMerchantDiscounts = null;
        BigDecimal targetExpertDiscounts = null;
        BigDecimal targetPayDiscounts = null;

        //这4个优惠字段，可能没有，也有可能为0！
        if (platformDiscounts != null && !"".equals(platformDiscounts) && !"0".equals(new BigDecimal(platformDiscounts).stripTrailingZeros().toPlainString())) {
            targetPlatformDiscounts = new BigDecimal(platformDiscounts);
        }
        if (merchantDiscounts != null && !"".equals(merchantDiscounts) && !"0".equals(new BigDecimal(merchantDiscounts).stripTrailingZeros().toPlainString())) {
            targetMerchantDiscounts = new BigDecimal(merchantDiscounts);
        }
        if (expertDiscounts != null && !"".equals(expertDiscounts) && !"0".equals(new BigDecimal(expertDiscounts).stripTrailingZeros().toPlainString())) {
            targetExpertDiscounts = new BigDecimal(expertDiscounts);
        }
        if (payDiscounts != null && !"".equals(payDiscounts) && !"0".equals(new BigDecimal(payDiscounts).stripTrailingZeros().toPlainString())) {
            targetPayDiscounts = new BigDecimal(payDiscounts);
        }

        /**
         * OFS销售订单明细行，没有分摊金额的几种情况：
         * 1.对应的OFS销售订单表头某个优惠字段为空或为0
         * 2.明细行没有实付金额或者为0，所以没有分摊比例，不参与分摊
         */
        BigDecimal totalShareTargetPlatformDiscounts = new BigDecimal("0");
        BigDecimal totalShareTargetMerchantDiscounts = new BigDecimal("0");
        BigDecimal totalShareTargetExpertDiscounts = new BigDecimal("0");
        BigDecimal totalShareTargetPayDiscounts = new BigDecimal("0");

        //分摊金额=分摊比例*优惠金额
        for (int i = 0; i < rerturnGoodsOrderSearchDetails.size(); i++) {
            RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails1 = rerturnGoodsOrderSearchDetails.get(i);
            //分摊比例
            BigDecimal sharingRatio = rerturnGoodsOrderSearchDetails1.getSharingRatio();

            //这里应该先8为小数，实际汇总到出库单时，再四舍五入两位小数
            BigDecimal shareTargetPlatformDiscounts = null;
            BigDecimal shareTargetMerchantDiscounts = null;
            BigDecimal shareTargetExpertDiscounts = null;
            BigDecimal shareTargetPayDiscounts = null;
            if (sharingRatio != null && targetPlatformDiscounts != null) {
                shareTargetPlatformDiscounts = targetPlatformDiscounts.multiply(sharingRatio).setScale(2, BigDecimal.ROUND_HALF_UP);
                rerturnGoodsOrderSearchDetails1.setOriginalTargetPlatformDiscounts(targetPlatformDiscounts);
                rerturnGoodsOrderSearchDetails1.setShareTargetPlatformDiscounts(shareTargetPlatformDiscounts);

                totalShareTargetPlatformDiscounts = totalShareTargetPlatformDiscounts.add(shareTargetPlatformDiscounts);
            }
            if (sharingRatio != null && targetMerchantDiscounts != null) {
                shareTargetMerchantDiscounts = targetMerchantDiscounts.multiply(sharingRatio).setScale(2, BigDecimal.ROUND_HALF_UP);
                rerturnGoodsOrderSearchDetails1.setOriginalTargetMerchantDiscounts(targetMerchantDiscounts);
                rerturnGoodsOrderSearchDetails1.setShareTargetMerchantDiscounts(shareTargetMerchantDiscounts);

                totalShareTargetMerchantDiscounts = totalShareTargetMerchantDiscounts.add(shareTargetMerchantDiscounts);
            }
            if (sharingRatio != null && targetExpertDiscounts != null) {
                shareTargetExpertDiscounts = targetExpertDiscounts.multiply(sharingRatio).setScale(2, BigDecimal.ROUND_HALF_UP);
                rerturnGoodsOrderSearchDetails1.setOriginalTargetExpertDiscounts(targetExpertDiscounts);
                rerturnGoodsOrderSearchDetails1.setShareTargetExpertDiscounts(shareTargetExpertDiscounts);

                totalShareTargetExpertDiscounts = totalShareTargetExpertDiscounts.add(shareTargetExpertDiscounts);
            }
            if (sharingRatio != null && targetPayDiscounts != null) {
                shareTargetPayDiscounts = targetPayDiscounts.multiply(sharingRatio).setScale(2, BigDecimal.ROUND_HALF_UP);
                rerturnGoodsOrderSearchDetails1.setOriginalTargetPayDiscounts(targetPayDiscounts);
                rerturnGoodsOrderSearchDetails1.setShareTargetPayDiscounts(shareTargetPayDiscounts);

                totalShareTargetPayDiscounts = totalShareTargetPayDiscounts.add(shareTargetPayDiscounts);
            }

            //如果是最后一行，则把尾差进行追加
            if (i == rerturnGoodsOrderSearchDetails.size() - 1) {
                if (!"0".equals(totalShareTargetPlatformDiscounts.stripTrailingZeros().toPlainString()) && rerturnGoodsOrderSearchDetails1.getShareTargetPlatformDiscounts() != null) {
                    //原始优惠金额-sum（分摊金额）
                    BigDecimal subtract = targetPlatformDiscounts.subtract(totalShareTargetPlatformDiscounts);
                    BigDecimal shareTargetPlatformDiscounts1 = rerturnGoodsOrderSearchDetails1.getShareTargetPlatformDiscounts();
                    if (subtract.compareTo(BigDecimal.ZERO) > 0) {
                        rerturnGoodsOrderSearchDetails1.setShareTargetPlatformDiscounts(shareTargetPlatformDiscounts1.add(subtract));
                    }
                }
                if (!"0".equals(totalShareTargetMerchantDiscounts.stripTrailingZeros().toPlainString()) && rerturnGoodsOrderSearchDetails1.getShareTargetMerchantDiscounts() != null) {
                    //原始优惠金额-sum（分摊金额）
                    BigDecimal subtract = targetMerchantDiscounts.subtract(totalShareTargetMerchantDiscounts);
                    BigDecimal shareTargetPlatformDiscounts1 = rerturnGoodsOrderSearchDetails1.getShareTargetMerchantDiscounts();
                    if (subtract.compareTo(BigDecimal.ZERO) > 0) {
                        rerturnGoodsOrderSearchDetails1.setShareTargetMerchantDiscounts(shareTargetPlatformDiscounts1.add(subtract));
                    }
                }
                if (!"0".equals(totalShareTargetExpertDiscounts.stripTrailingZeros().toPlainString()) && rerturnGoodsOrderSearchDetails1.getShareTargetExpertDiscounts() != null) {
                    BigDecimal subtract = targetExpertDiscounts.subtract(totalShareTargetExpertDiscounts);
                    BigDecimal shareTargetExpertDiscounts1 = rerturnGoodsOrderSearchDetails1.getShareTargetExpertDiscounts();
                    if (subtract.compareTo(BigDecimal.ZERO) > 0) {
                        rerturnGoodsOrderSearchDetails1.setShareTargetExpertDiscounts(shareTargetExpertDiscounts1.add(subtract));
                    }
                }
                if (!"0".equals(totalShareTargetPayDiscounts.stripTrailingZeros().toPlainString()) && rerturnGoodsOrderSearchDetails1.getShareTargetPayDiscounts() != null) {
                    BigDecimal subtract = targetPayDiscounts.subtract(totalShareTargetPayDiscounts);
                    BigDecimal shareTargetPayDiscounts1 = rerturnGoodsOrderSearchDetails1.getShareTargetPayDiscounts();
                    if (subtract.compareTo(BigDecimal.ZERO) > 0) {
                        rerturnGoodsOrderSearchDetails1.setShareTargetPayDiscounts(shareTargetPayDiscounts1.add(subtract));
                    }
                }
            }

            //拷贝回到原始的集合
            copyDetailsDtoOld(rerturnGoodsOrderSearchDetails, detailsOld);
        }
        logger.info("==TOC退货金额分摊结束==");
    }

    /**
     * 计算百分比
     * 分摊比例=零售价/sum(零售价)
     *
     * @param rerturnGoodsOrderSearchData       OFS售后订单
     * @param rerturnGoodsOrderSearchDetailsOld 过滤前的售后订单
     * @param ofsCode                           OFS售后订单号
     * @author liuyang
     */
    private void calculatePercentage(RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData, List<RerturnGoodsOrderSearchDetails> rerturnGoodsOrderSearchDetailsOld, String ofsCode) throws Exception {
        Assert.notNull(rerturnGoodsOrderSearchData, "headerDetailsDto2不能为空");
        RerturnGoodsOrderSearchHeader header = rerturnGoodsOrderSearchData.getHeader();
        List<RerturnGoodsOrderSearchDetails> details = rerturnGoodsOrderSearchData.getDetails();

        BigDecimal sumActualPaymentAmountBigDecimal = sumActualPaymentAmount(details, header.getCode());
        for (int i = 0; i < details.size(); i++) {
            RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = details.get(i);
            //如果实付金额为0则不进行分摊！
            String msrPrice = rerturnGoodsOrderSearchDetails.getMsrPrice();
            if (msrPrice != null && !"0".equals(new BigDecimal(msrPrice).stripTrailingZeros().toPlainString())) {
                BigDecimal msrPriceBigDecimal = new BigDecimal(msrPrice);
                //得到分摊比例
                BigDecimal percentageBigDecimal = msrPriceBigDecimal.divide(sumActualPaymentAmountBigDecimal, 20, BigDecimal.ROUND_HALF_UP).setScale(8, BigDecimal.ROUND_HALF_UP);
                if (rerturnGoodsOrderSearchDetailsOld != null && rerturnGoodsOrderSearchDetailsOld.size() > 0) {
                    for (int j = 0; j < rerturnGoodsOrderSearchDetailsOld.size(); j++) {
                        RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails1 = rerturnGoodsOrderSearchDetailsOld.get(j);
                        if (rerturnGoodsOrderSearchDetails1.getId() != null && rerturnGoodsOrderSearchDetails.getId() != null) {
                            if (rerturnGoodsOrderSearchDetails1.getId().equals(rerturnGoodsOrderSearchDetails.getId())) {
                                rerturnGoodsOrderSearchDetails1.setSharingRatio(percentageBigDecimal);
                            }
                        }
                    }
                }
            } else {
                logger.info("msrPrice(商品零售价)为空！OFS售后订单号：{} 存货编码：{}", ofsCode, rerturnGoodsOrderSearchDetails.getSkuCode());
            }
        }
    }

    /**
     * 累计这一单对应的实付金额
     *
     * @param details OFS销售订单明细行
     * @param code    OFS售后订单号
     * @author liuyang
     */
    private BigDecimal sumActualPaymentAmount(List<RerturnGoodsOrderSearchDetails> details, String code) throws Exception {
        Assert.notNull(details, "details1不能为空");
        Assert.notNull(code, "code不能为空");

        BigDecimal actualPaymentAmountBigDecimal = new BigDecimal("0");
        for (int i = 0; i < details.size(); i++) {
            RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = details.get(i);

            String msrPrice = rerturnGoodsOrderSearchDetails.getMsrPrice();
//            if (msrPrice == null || "".equals(msrPrice.trim())) {
//                Assert.state(false, "售后订单零售价不能为空 OFS售后订单号：{}", code);
//            }
            if (msrPrice != null && !"0".equals(new BigDecimal(msrPrice).stripTrailingZeros().toPlainString())) {
                BigDecimal msrPriceBigDecimal = new BigDecimal(msrPrice);
                actualPaymentAmountBigDecimal = actualPaymentAmountBigDecimal.add(msrPriceBigDecimal);
                logger.info("商品零售价：{}", msrPrice);
            }
        }
//        if ("0".equals(actualPaymentAmountBigDecimal.stripTrailingZeros().toPlainString())) {
//            Assert.state(false, "售后订单零售价(合并后)不能为0 OFS售后订单号：{}", code);
//        }
        if ("0".equals(actualPaymentAmountBigDecimal.stripTrailingZeros().toPlainString())) {
            logger.info("售后订单零售价(合并后)全部为0，所有的明细行不参与分摊！ OFS售后订单号：{}", code);
        }
        return actualPaymentAmountBigDecimal;
    }

    /**
     * 集合复制
     *
     * @param details 旧OFS售后订单明细行
     * @author liuyang
     */
    private List<RerturnGoodsOrderSearchDetails> copyDetailsDto(List<RerturnGoodsOrderSearchDetails> details) throws Exception {
        List<RerturnGoodsOrderSearchDetails> newDetails = new ArrayList<>();
        for (int i = 0; i < details.size(); i++) {
            RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = details.get(i);

            RerturnGoodsOrderSearchDetails newDetailsDto1 = new RerturnGoodsOrderSearchDetails();
            BeanUtil.copyPropertiesV2(rerturnGoodsOrderSearchDetails, newDetailsDto1);
            newDetails.add(newDetailsDto1);
        }
        return newDetails;
    }

    /**
     * 拷贝到原集合中
     *
     * @param newDetails 新OFS销售订单明细行
     * @param detailsOld 旧OFS销售订单明细行
     * @author liuyang
     */
    private void copyDetailsDtoOld(List<RerturnGoodsOrderSearchDetails> newDetails, List<RerturnGoodsOrderSearchDetails> detailsOld) throws Exception {
        if (newDetails != null && detailsOld != null) {
            for (int i = 0; i < detailsOld.size(); i++) {
                RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = detailsOld.get(i);
                for (int j = 0; j < newDetails.size(); j++) {
                    RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails1 = newDetails.get(j);
                    if (rerturnGoodsOrderSearchDetails.getId().equals(rerturnGoodsOrderSearchDetails1.getId())) {
                        //把分摊后的金额拷贝到旧的OFS销售订单集合中
                        BeanUtil.copyPropertiesV2(rerturnGoodsOrderSearchDetails1, rerturnGoodsOrderSearchDetails);
                    }
                }
            }
        } else {
            logger.error("copyDetailsDtoOld方法newDetails或者detailsOld为空！");
        }
    }

    /**
     * 打印金额参数
     *
     * @param rerturnGoodsOrderSearchDataList OFS售后订单集合
     */
    public void printAmountOfMoneyNum(List<RerturnGoodsOrderSearchData> rerturnGoodsOrderSearchDataList) {
        try {
            if (rerturnGoodsOrderSearchDataList != null && rerturnGoodsOrderSearchDataList.size() > 0) {
                for (int i = 0; i < rerturnGoodsOrderSearchDataList.size(); i++) {
                    RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData = rerturnGoodsOrderSearchDataList.get(i);
                    RerturnGoodsOrderSearchHeader header = rerturnGoodsOrderSearchData.getHeader();
                    List<RerturnGoodsOrderSearchDetails> details = rerturnGoodsOrderSearchData.getDetails();

                    logger.info("OFS售后订单号：{} 平台优惠：{} 商家优惠：{} 达人优惠：{} 支付优惠：{}", header.getCode(), header.getPlatformDiscounts(), header.getMerchantDiscounts(), header.getExpertDiscounts(), header.getPayDiscounts());
                    if (details != null && details.size() > 0) {
                        for (int j = 0; j < details.size(); j++) {
                            RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = details.get(j);

                            logger.info("start================================");
                            logger.info("OFS售后订单明细主键：{}", rerturnGoodsOrderSearchDetails.getId());
                            if (rerturnGoodsOrderSearchDetails.getSharingRatio() != null) {
                                logger.info("分摊比例：{}", rerturnGoodsOrderSearchDetails.getSharingRatio().stripTrailingZeros().toPlainString());
                            } else {
                                logger.info("分摊比例：无");
                            }
                            logger.info("商品零售价：{}", rerturnGoodsOrderSearchDetails.getMsrPrice());
                            if (rerturnGoodsOrderSearchDetails.getShareTargetPlatformDiscounts() != null) {
                                logger.info("分摊平台优惠：{}", rerturnGoodsOrderSearchDetails.getShareTargetPlatformDiscounts().stripTrailingZeros().toPlainString());
                            } else {
                                logger.info("分摊平台优惠：无");
                            }
                            if (rerturnGoodsOrderSearchDetails.getShareTargetMerchantDiscounts() != null) {
                                logger.info("分摊商家优惠：{}", rerturnGoodsOrderSearchDetails.getShareTargetMerchantDiscounts().stripTrailingZeros().toPlainString());
                            } else {
                                logger.info("分摊商家优惠：无");
                            }
                            if (rerturnGoodsOrderSearchDetails.getShareTargetExpertDiscounts() != null) {
                                logger.info("分摊达人优惠：{}", rerturnGoodsOrderSearchDetails.getShareTargetExpertDiscounts().stripTrailingZeros().toPlainString());
                            } else {
                                logger.info("分摊达人优惠：无");
                            }
                            if (rerturnGoodsOrderSearchDetails.getShareTargetPayDiscounts() != null) {
                                logger.info("分摊支付优惠：{}", rerturnGoodsOrderSearchDetails.getShareTargetPayDiscounts().stripTrailingZeros().toPlainString());
                            } else {
                                logger.info("分摊支付优惠：无");
                            }
                            logger.info("end================================");
                        }
                    }
                }
            }
        } catch (Exception e) {
            logger.error("printAmountOfMoneyNum方法抛出异常", e);
        }
    }
}